Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2715)

Unified Diff: chrome/browser/ui/views/frame/glass_browser_frame_view.h

Issue 1412833008: Draw the same portion of the frame background behind the tabstrip in maximized (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@match_frame_alignment
Patch Set: Add comment Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/frame/glass_browser_frame_view.h
diff --git a/chrome/browser/ui/views/frame/glass_browser_frame_view.h b/chrome/browser/ui/views/frame/glass_browser_frame_view.h
index 21871be62ccd0e3aeabbb97369ce771e28f536ee..0bf9fa578a3f8b4be983446698c73637048754a3 100644
--- a/chrome/browser/ui/views/frame/glass_browser_frame_view.h
+++ b/chrome/browser/ui/views/frame/glass_browser_frame_view.h
@@ -21,7 +21,7 @@ class GlassBrowserFrameView : public BrowserNonClientFrameView,
// BrowserNonClientFrameView:
gfx::Rect GetBoundsForTabStrip(views::View* tabstrip) const override;
- int GetTopInset() const override;
+ int GetTopInset(bool restored) const override;
int GetThemeBackgroundXInset() const override;
void UpdateThrobber(bool running) override;
gfx::Size GetMinimumSize() const override;
@@ -57,16 +57,22 @@ class GlassBrowserFrameView : public BrowserNonClientFrameView,
// and bottom frame edges. This does not include any client edge.
int FrameBorderThickness() const;
- // Returns the height of the window top frame edge.
- int FrameTopBorderHeight() const;
+ // Returns the height of the window top frame edge. If |restored| is true,
+ // this is calculated as if the window was restored, regardless of its current
+ // state.
+ int FrameTopBorderHeight(bool restored) const;
// Returns the thickness of the entire nonclient left, right, and bottom
- // borders, including both the window frame and any client edge.
- int NonClientBorderThickness() const;
+ // borders, including both the window frame and any client edge. If |restored|
+ // is true, this is calculated as if the window was restored, regardless of
+ // its current state.
+ int NonClientBorderThickness(bool restored) const;
// Returns the height of the entire nonclient top border, including the window
- // frame, any title area, and any connected client edge.
- int NonClientTopBorderHeight() const;
+ // frame, any title area, and any connected client edge. If |restored| is
+ // true, this is calculated as if the window was restored, regardless of its
+ // current state.
+ int NonClientTopBorderHeight(bool restored) const;
// Paint various sub-components of this view.
void PaintToolbarBackground(gfx::Canvas* canvas);
@@ -77,8 +83,9 @@ class GlassBrowserFrameView : public BrowserNonClientFrameView,
void LayoutNewStyleAvatar();
void LayoutClientView();
- // Returns the insets of the client area.
- gfx::Insets GetClientAreaInsets() const;
+ // Returns the insets of the client area. If |restored| is true, this is
+ // calculated as if the window was restored, regardless of its current state.
+ gfx::Insets GetClientAreaInsets(bool restored) const;
// Returns the bounds of the client area for the specified view size.
gfx::Rect CalculateClientAreaBounds(int width, int height) const;
« no previous file with comments | « chrome/browser/ui/views/frame/browser_view_unittest.cc ('k') | chrome/browser/ui/views/frame/glass_browser_frame_view.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698